==> v1.2.2.tar.gz: ssgf_utils/weipinshang_api/req.go <==
package weipinshang_api

type CreateAfsApplyReq struct {
	McOrderNo           int    `json:"mcOrderNo"`           // 子订单号	是	int	下单时候返回子订单号	20190704124955600363
	CustomerExpect      int    `json:"customerExpect"`      //  售后类型 	是	int	[退货(10)、仅退款(40)]	10
	QuestionDesc        string `json:"questionDesc"`        // 原因描述	否	String	[产品问题描述，最多600字符]	看下面请求示例
	QuestionPic         string `json:"questionPic"`         //问题描述图片	否	String	[问题描述图片.最多2000字符]		支持多张图片，用逗号分隔（英文逗号）
	CustomerContactName string `json:"customerContactName"` // 用户姓名	是	String	[用户姓名]	张三
	CustomerTel         string `json:"customerTel"`         // 用户电话	是	String	[用户电话]	18533136240
	CustomerMobilePhone string `json:"customerMobilePhone"` //  用户手机	是	String	[用户手机]	18533136240
	PickwareProvince    string `json:"pickwareProvince"`    //省份	是	String	[省份]	湖南
	PickwareCity        string `json:"pickwareCity"`        //  城市	是	String	[城市]	长沙
	PickwareCounty      string `json:"pickwareCounty"`      //   县区	是	String	[县区] 	芙蓉区
	PickwareAddress     string `json:"pickwareAddress"`     //详细地址	是	String	[县区]	塔南路59号2号楼2单元1301室
}

type GetManyPostageReq struct {
	GoodsInfo string `json:"goodsInfo"` //商品数组	goodsInfo	是	json		需要转成json形式的字符串
	Address   string `json:"address"`   // 详细地址	address	是	String
	County    string `json:"county"`    // 区	county	是	String
	Province  string `json:"province"`  //省份	province	是	String
	City      string `json:"city"`      //城市	city	是	String
}

type PreOrderReq struct {
	LockCode          string `json:"lockCode"`          //预下单编码	lockCode	是	String
	ConsigneeContacts string `json:"consigneeContacts"` //收货人姓名	consigneeContacts	是	String
	ConsigneePhone    string `json:"consigneePhone"`    //收货人手机号	consigneePhone	是	String
	Province          string `json:"province"`          //省份	province	是	String
	City              string `json:"city"`              //城市	city	是	String
	Address           string `json:"address"`           // 详细地址	address	是	String
	Area              string `json:"area"`              //区	area	是	String		区
	GoodsInfo         string `json:"goodsInfo"`         //商品数组	goodsInfo	是	json		需要转成json形式的字符串
	Source            string `json:"source"`            //订单来源 请求渠道号
}

type GoodsInfo struct {
	GoodSpecId string `json:"goodSpecId"` //商品ID	goodSpecId	是	String		商品ID(c_goods_id)
	GoodsId    string `json:"goodsId"`    //商品父	goodsId	是	String		商品父ID(c_father_goods_id)
	Num        string `json:"num"`        // 数量
}

type CreateOrderReq struct {
	LockCode  string `json:"lockCode"`  //预下单编码	lockCode	是	String
	OrderNo   string `json:"orderNo"`   //对接方业务单号	orderNo	是	String
	NoticeUrl string `json:"noticeUrl"` //合作方通知地址	noticeUrl	否	String	规定值	如支持，订单更新实时通知。此参数可不用传，统一走异步回调
}

==> v1.2.6.tar.gz: ssgf_utils/weipinshang_api/req.go <==
package weipinshang_api

type CreateAfsApplyReq struct {
	McOrderNo           int    `json:"mcOrderNo"`           // 子订单号	是	int	下单时候返回子订单号	20190704124955600363
	CustomerExpect      int    `json:"customerExpect"`      //  售后类型 	是	int	[退货(10)、仅退款(40)]	10
	QuestionDesc        string `json:"questionDesc"`        // 原因描述	否	String	[产品问题描述，最多600字符]	看下面请求示例
	QuestionPic         string `json:"questionPic"`         //问题描述图片	否	String	[问题描述图片.最多2000字符]		支持多张图片，用逗号分隔（英文逗号）
	CustomerContactName string `json:"customerContactName"` // 用户姓名	是	String	[用户姓名]	张三
	CustomerTel         string `json:"customerTel"`         // 用户电话	是	String	[用户电话]	18533136240
	CustomerMobilePhone string `json:"customerMobilePhone"` //  用户手机	是	String	[用户手机]	18533136240
	PickwareProvince    string `json:"pickwareProvince"`    //省份	是	String	[省份]	湖南
	PickwareCity        string `json:"pickwareCity"`        //  城市	是	String	[城市]	长沙
	PickwareCounty      string `json:"pickwareCounty"`      //   县区	是	String	[县区] 	芙蓉区
	PickwareAddress     string `json:"pickwareAddress"`     //详细地址	是	String	[县区]	塔南路59号2号楼2单元1301室
}

type GetManyPostageReq struct {
	GoodsInfo string `json:"goodsInfo"` //商品数组	goodsInfo	是	json		需要转成json形式的字符串
	Address   string `json:"address"`   // 详细地址	address	是	String
	County    string `json:"county"`    // 区	county	是	String
	Province  string `json:"province"`  //省份	province	是	String
	City      string `json:"city"`      //城市	city	是	String
}

type PreOrderReq struct {
	LockCode          string `json:"lockCode"`          //预下单编码	lockCode	是	String
	ConsigneeContacts string `json:"consigneeContacts"` //收货人姓名	consigneeContacts	是	String
	ConsigneePhone    string `json:"consigneePhone"`    //收货人手机号	consigneePhone	是	String
	Province          string `json:"province"`          //省份	province	是	String
	City              string `json:"city"`              //城市	city	是	String
	Address           string `json:"address"`           // 详细地址	address	是	String
	Area              string `json:"area"`              //区	area	是	String		区
	GoodsInfo         string `json:"goodsInfo"`         //商品数组	goodsInfo	是	json		需要转成json形式的字符串
	Source            string `json:"source"`            //订单来源 请求渠道号
}

type GoodsInfo struct {
	GoodSpecId string `json:"goodSpecId"` //SKU ID	goodSpecId	是	String		商品ID(c_goods_id)
	GoodsId    string `json:"goodsId"`    //商品ID	goodsId	是	String		商品父ID(c_father_goods_id)
	Num        string `json:"num"`        // 数量
}

type CreateOrderReq struct {
	LockCode  string `json:"lockCode"`  //预下单编码	lockCode	是	String
	OrderNo   string `json:"orderNo"`   //对接方业务单号	orderNo	是	String
	NoticeUrl string `json:"noticeUrl"` //合作方通知地址	noticeUrl	否	String	规定值	如支持，订单更新实时通知。此参数可不用传，统一走异步回调
}

// test ------------------------------------------------

type DeliverGoodsReq struct {
	COrderItemNo  string `json:"c_order_item_no"` //c_order_item_no	子订单号	是	int	下单时候返回子订单号	20190704124955600363
	CDeliveryName string `json:"c_delivery_name"` //  快递公司
	CDeliveryNo   string `json:"c_delivery_no"`   //  快递单号
}

type UpdateServiceReq struct {
	COrderItemNo string `json:"c_order_item_no"` //c_order_item_no	子订单号	是	int	下单时候返回子订单号	20190704124955600363
	CType        string `json:"c_type"`          //c_type	快递名称	是	String	[处理类型 1 同意售后 2 拒绝 3 退款完成]
}
